/*========================================================================
 * attrtest - get SDS attributes
 *
 * 27-Aug-2002 K.Knowles knowlesk@kryos.colorado.edu 303-492-0644
 * National Snow & Ice Data Center, University of Colorado, Boulder
 *========================================================================*/
#include <stdio.h>
#include "hdf.h"
#include "mfhdf.h"

#define check_hdf_error(io_status, description)	\
if (FAIL == io_status)				\
{ fprintf(stderr,"error: %s\n", description);	\
  HEprint(stderr, 0);				\
}

int main(int argc, char *argv[]) {
  int ios;
  int32 file_id, dims[2], start[2]={0,0};
  int32 sds_index, sds_id, rank, ntype, nattrs, attr_index;
  float32 Tb_scale=0.01, Tb_offset=327.679993;
  char sds_name[] = "6.9V_Res.1_TB_(Level1B)";
  char error_msg[MAX_NC_NAME], name[MAX_NC_NAME];

  if (argc != 2) {
    fprintf(stderr, "usage: attrtest filename.hdf\n");
    exit(EXIT_FAILURE);
  }

  file_id = SDstart(argv[1], DFACC_RDONLY);
  if (FAIL == file_id) {
    fprintf(stderr, "error starting SD access\n"); 
    perror(argv[1]);
  }

  strcpy(error_msg, sds_name);

/*
 * convert name to ID, get dimensions, etc.
 */
  sds_index = SDnametoindex(file_id, sds_name);
  check_hdf_error(sds_index, strcat(error_msg, ": index from name"));

  sds_id = SDselect(file_id, sds_index);
  check_hdf_error(sds_id, strcat(error_msg, ": ID from index"));
      
  ios = SDgetinfo(sds_id, name, &rank, dims, &ntype, &nattrs);
  check_hdf_error(ios, strcat(error_msg, ": dimensions"));

  printf("found SDS #%1d \"%s\"(%1dx%1d) with %d attributes\n", 
	    sds_index, name, dims[0], dims[1], nattrs); 

/*
 * make sure data type and dimensions match expectations
 */
  if (rank != 2 || ntype != DFNT_INT16) {
    fprintf(stderr, "%s: rank or data type mismatch\n", sds_name);
  }

/*
 * read scale and offset attributes
 */
  if (nattrs >= 2) { 
    attr_index = SDfindattr(sds_id, "Tb_scale");
    ios = SDreadattr(file_id, attr_index, (VOIDP)&Tb_scale);
    check_hdf_error(ios, "reading Tb_scale attribute");

    printf("Tb_scale = %f\n", Tb_scale);

    attr_index = SDfindattr(sds_id, "Tb_offset");
    ios = SDreadattr(file_id, attr_index, (VOIDP)&Tb_offset);
    check_hdf_error(ios, "reading Tb_offset attribute");

    printf("Tb_offset = %f\n", Tb_offset);

  }
}
