/*--------------------------------------------------------------------------
 * gslicer.h - manages sliced subsets of generic swath files
 *
 * SMMR and SSM/I defaults for begin_hhmmss and subset_lengths are specific,
 * defaults are not specific for other GS_types.
 *
 * 02/16/1998 brodzik brodzik@kryos.colorado.edu 303-492-8263
 * National Snow & Ice Data Center, University of Colorado, Boulder
 * Copyright (C) 1998 University of Colorado
 *--------------------------------------------------------------------------*/
#ifndef gslicer_h_
#define gslicer_h_

#ifdef gslicer_c_
const char gslicer_h_rcsid[]="$Header: /NSIDC_CVS/FILES/generic_swath/src/gsconcat/gslicer.h,v 1.8 2004/01/29 23:17:42 brodzik Exp $";
#endif

#include "define.h"
#include "gswath.h"

#define GSLICER_DEFAULT_BEGIN_HHMMSS BYTE4_MAX
#define GSLICER_DEFAULT_SUBSET_LENGTH_SEC 0

/* 
 * Return values from compare_time_to_gslicer
 */
typedef enum { PRIOR_TO_GSFILE,
	       DURING_GSFILE, 
	       LATER_THAN_GSFILE } gslicer_time_comparison;


/*
 * gslicer manager
 */
typedef struct {
    char *pathname;
    char *fileid;
    char *filename;
    FILE *fp;
    byte4 start_timecode;
    byte4 end_timecode;
    char *scan_id;
    GS_type swath_type;
    byte4 num_gswaths;
} gslicer_class;

gslicer_class *init_gslicer(const char *pathname, 
			    const byte4 start_timecode,
			    const byte4 subset_length, 
			    const char *infilename,
			    const GS_type swath_type,
			    bool verbose);
gslicer_time_comparison compare_time_to_gslicer(gslicer_class *this, 
					 const byte4 timecode);
bool append_gslicer(gslicer_class *this, GSwath *gs, int channel[]);
bool next_gslicer(gslicer_class *this, FILE *notify_fp, bool verbose);
void close_gslicer(gslicer_class *this, FILE *notify_fp);

byte4 default_begin_yyyymmdd_gslicer(void);
byte4 default_end_yyyymmdd_gslicer(void);

#endif
