/*--------------------------------------------------------------------------
 * struct_amsr.h - contains the structures used in AMSR gridding programs
 *
 * 17-Jul-2002 K.Knowles knowlesk@kryos.colorado.edu 303-492-0644
 * National Snow & Ice Data Center, University of Colorado, Boulder
 * Copyright (C) 2002-2004 University of Colorado
 *--------------------------------------------------------------------------*/
#ifndef struct_amsr_h_
#define struct_amsr_h_

#ifdef gswath_c_
const char struct_amsr_h_rcsid[]="$Header: /NSIDC_CVS/FILES/generic_swath/src/gswath/struct_amsr.h,v 1.5 2004/01/23 01:57:57 knowlesk Exp $";
#endif

#include "define.h"

/* 
 * AMSR satellite platforms 
 */
typedef enum { AQUA, AMSR_NUM_SATS
} amsr_sat_designator;

static const int amsr_sat_number[] = { 0 };
static const char *amsr_sat_name[] = { "AQUA" };

/*
 *  Local time of first ascending node, in decimal hours
 *  References: 
 */
static const float amsr_asc_node_hour[] = { 13.50 };
static const float amsr_des_node_hour[] = {  1.50 };

/* AMSR channel indices */
typedef enum {
  AMSR_06V, AMSR_06H, AMSR_10V, AMSR_10H, AMSR_18V, 
  AMSR_18H, AMSR_23V, AMSR_23H, AMSR_36V, AMSR_36H,
  AMSR_89V, AMSR_89H, AMSR_RES1_CHANNELS
} amsr_res1_channel_designator;

typedef enum {
  AMSR_89Vr5, AMSR_89Hr5, AMSR_RES5_CHANNELS
} amsr_res5_channel_designator;

static const char *amsr_channel_name[] = {
    "06V", "06H", "10V", "10H", "18V", "18H",
    "23V", "23H", "36V", "36H", "89V", "89H" };

static float amsr_Tb_min_Kelvins[] = {
    55,  55,  55,  55,  55,  55,  
    55,  55,  55,  55,  55,  55 };
static float amsr_Tb_max_Kelvins[] = { 
    319.99, 319.99, 319.99, 319.99, 319.99, 319.99, 
    319.99, 319.99, 319.99, 319.99, 319.99, 319.99 };

/*
 * res1 == lowres == 10km
 * res5 == hires  ==  5km
 */
#define AMSR_RECS_PER_RES1_SCAN 243
#define AMSR_RECS_PER_RES5_SCAN 486
#define AMSR_SEC_PER_SCAN 1.5
#define AMSR_SEC_PER_ORBIT 5928
#define AMSR_DECLINATION 8.2
#define AMSR_RES1_km 10.0
#define AMSR_RES5_km 5.0
#define AMSR_TEMP_SCALE 0.01

/*
 *  scan line data structures
 */
struct AMSR_RES1_SPOT {
    float lat; /* latitude */
    float lon; /* longitude */
    float eia; /* Earth incidence angle */
    byte2 temp[AMSR_RES1_CHANNELS];
};

struct AMSR_RES1_SCAN {
    byte4 time; /* TAI93 - seconds since 1 Jan 1993 */
    int2 qflag; /* scan quality flag */
    struct AMSR_RES1_SPOT pos[AMSR_RECS_PER_RES1_SCAN];
};

struct AMSR_RES5_SPOT {
    float lat; /* latitude */
    float lon; /* longitude */
    float eia; /* Earth incidence angle */
    byte2 temp[AMSR_RES5_CHANNELS];
};

struct AMSR_RES5_SCAN {
    byte4 time; /* TAI93 - seconds since 1 Jan 1993 */
    int2 qflag; /* scan quality flag */
  struct AMSR_RES5_SPOT pos[AMSR_RECS_PER_RES5_SCAN];
};

#endif /* end of struct_amsr.h */
