/*--------------------------------------------------------------------------
 * struct_smmr.h - contains the structures used in SMMR gridding programs
 *
 * 02-Sep-1998 K.Knowles knowlesk@kryos.colorado.edu 303-492-0644
 * National Snow & Ice Data Center, University of Colorado, Boulder
 * Copyright (C) 1998 University of Colorado
 *--------------------------------------------------------------------------*/
#include "define.h"

#ifndef struct_smmr_h_
#define struct_smmr_h_

#ifdef gswath_c_
const char struct_smmr_h_rcsid[]="$Header: /NSIDC_CVS/FILES/generic_swath/src/gswath/struct_smmr.h,v 1.7 2004/01/23 01:57:57 knowlesk Exp $";
#endif

/* SMMR channel indices into structure arrays */
typedef enum 
{ TB06H, TB06V, TB10H, TB10V, TB18H, TB18V, 
    TB21H, TB21V, TB37H, TB37V, SMMR_NUM_CHAN 
} smmr_channel_designator;

static const char *smmr_channel_name[] = 
{ "06H", "06V", "10H", "10V", "18H", "18V", 
    "21H", "21V", "37H", "37V" };

static float smmr_Tb_min[] =
{   65,    65,    65,    65,    65,    65,    65,    65,    65,    65  };
static float smmr_Tb_max[] =
{  320,  320,    320,   320,   320,   320,   320,   320,   320,   320  };

#define SMMR_SEC_PER_ORBIT (60*104.16)
#define SMMR_SEC_PER_SCAN 4.096
#define SMMR_DECLINATION 9.9
#define SMMR_NOMINAL_RES_km 25.0

#define SMMR_RECS_PER_SCAN 94
#define SMMR_SCANS_PER_ORBIT 1600

/* Biases and scaling factors for storage of lat and lon and temperatures */
#define SMMR_LAT_BIAS 90.0
#define SMMR_LAT_SCALE 0.01
#define SMMR_LON_BIAS 180.0
#define SMMR_LON_SCALE 0.01
#define SMMR_TEMP_SCALE 0.1
#define SMMR_TIME_SCALE 0.1

/*
 *  Full SMMR record, without time
 *  Stores latitude (in unsigned range 0 to 18000), 
 *  longitude (in unsigned range 0 to 36000)
 *  and an array of Brightness temperatures for
 *  10 channels (5 frequencies by 2 polarizations)
 *  to be indexed by channel constants defined above
 *  (Use biases, above, for conversions).
 */
struct SMMR_REC_NT {
  byte2 lat;
  byte2 lon;
  byte2 temp[SMMR_NUM_CHAN];
};

/*
 *  smmr_time is in seconds since the beginning of 1978 (the launch year)
 */
struct SMMR_REC {
  int gmt_year;
  int gmt_doy;
  float gmt_seconds;
  byte2 status;
  byte4 smmr_time;
  bool ascending;
  struct SMMR_REC_NT full[SMMR_RECS_PER_SCAN];
};

#endif




