/***********************************************************************\
| Copyright  1997, by Philip David Howard - all rights reserved	|
|									|
| author	Philip D. Howard					|
| email		phil@txics.com, phil@milepost.com			|
| postal	Suite 129						|
|		17023 Preston Road					|
|		Dallas, Texas  75230					|
\***********************************************************************/

#include <stddef.h>
#include <time.h>

#include "days.h"

#pragma section begin SYNOPSIS
/***********************************************************************\
| function	jdn_to_time						|
|									|
| purpose	Convert a Julian Day Number to ANSI Standard C time_t	|
|		value for midnight at the beginning of the day.		|
|									|
| argument	1 (long) the Julian Day Number				|
|									|
| returns	(time_t) the time value at the beginning of the day.	|
|									|
| note		A Julian Day Number (JDN) is a Julian Date rounded	|
|		to an integer.  The Julian Date is commonly used in	|
|		astronomy to identify dates in ephemeral data and	|
|		formulas.  The JDN is a number that is the same		|
|		through the ordinary civil day and can be used for	|
|		calendar references.					|
|									|
| ref		Explanatory Supplement to the Astronomical Almanac,	|
|		P. Kenneth Seidelmann, editor  [ISBN 0-935702-68-7]	|
|		http://www.amazon.com/exec/obidos/ISBN=0935702687	|
\***********************************************************************/
#pragma section end SYNOPSIS

#define FUNCTION_NAME "jdn_to_time"

#pragma section begin FUNCTION
time_t
jdn_to_time (
	long	day
)
#pragma section end FUNCTION

#pragma section begin CODE
{
    struct tm ts;
    jdn_to_tm( day , & ts );
    return mktime( & ts );
}
#pragma section end CODE

#undef FUNCTION_NAME
