/***********************************************************************\
| Copyright  1997, by Philip David Howard - all rights reserved	|
|									|
| author	Philip D. Howard					|
| email		phil@txics.com, phil@milepost.com			|
| postal	Suite 129						|
|		17023 Preston Road					|
|		Dallas, Texas  75230					|
\***********************************************************************/

#include <stddef.h>
#include <stdlib.h>
#include <time.h>

#include "days.h"

#pragma section begin SYNOPSIS
/***********************************************************************\
| function	jdn_to_tm						|
|									|
| purpose	Convert a Julian Day Number to ANSI Standard C		|
|		struct tm filled in (and allocated if needed).		|
|									|
| arguments	1 (long) the Julian Day Number				|
|		2 (struct tm *) struct to fill in or NULL to allocate	|
|									|
| returns	(struct tm *) given or allocated (struct tm) pointer	|
|		(struct tm *) NULL if error				|
|									|
| note		A Julian Day Number (JDN) is a Julian Date rounded	|
|		to an integer.  The Julian Date is commonly used in	|
|		astronomy to identify dates in ephemeral data and	|
|		formulas.  The JDN is a number that is the same		|
|		through the ordinary civil day and can be used for	|
|		calendar references.					|
|									|
| ref		Explanatory Supplement to the Astronomical Almanac,	|
|		P. Kenneth Seidelmann, editor  [ISBN 0-935702-68-7]	|
|		http://www.amazon.com/exec/obidos/ISBN=0935702687	|
\***********************************************************************/
#pragma section end SYNOPSIS

#define FUNCTION_NAME "jdn_to_tm"

#pragma section begin FUNCTION
struct tm *
jdn_to_tm (
	long	day
,
	struct tm *	tm_p
)
#pragma section end FUNCTION

#pragma section begin CODE
{
    long year;

    if ( ! tm_p ) {
	tm_p = malloc( sizeof (struct tm) );
	if ( ! tm_p ) return NULL;
    }

    jdn_to_ymdg(day,
	   & year,
	   (unsigned int *) & tm_p -> tm_mon,
	   (unsigned int *) & tm_p -> tm_mday,
	   NULL,
	   (unsigned int *) & tm_p -> tm_yday
    );

    tm_p -> tm_mon ++;
    tm_p -> tm_year = year - 1900;
    tm_p -> tm_wday = ( day + 1 ) % 7;

    tm_p -> tm_sec   = 0;
    tm_p -> tm_min   = 0;
    tm_p -> tm_hour  = 0;
    tm_p -> tm_isdst = 0;

    return tm_p;
}
#pragma section end CODE

#undef FUNCTION_NAME
