/***********************************************************************\
| Copyright  1997, by Philip David Howard - all rights reserved	|
|									|
| author	Philip D. Howard					|
| email		phil@txics.com, phil@milepost.com			|
| postal	Suite 129						|
|		17023 Preston Road					|
|		Dallas, Texas  75230					|
\***********************************************************************/

#include <limits.h>
#include <stdio.h>

#include "days.h"

#pragma section begin SYNOPSIS
/***********************************************************************\
| command	testdate						|
|									|
| purpose	to test the date functions				|
|									|
| usage		testdate from by to					|
\***********************************************************************/
#pragma section end SYNOPSIS

#define COMMAND_NAME "testdate"

#pragma section begin MAIN
int
main (
	int		argc
,
	char * *	argv
)
#pragma section end MAIN

#pragma section begin CODE
{
    long dayf,dayb,dayt,dayn,dayx,gy,jy;
    unsigned int gd,gl,gm,gn,jd,jl,jm,jn;
    int w,abort;

    int diff;

    const char *daylist[7] = {"Sun","Mon","Tue","Wed","Thu","Fri","Sat"};

    diff = 0;

    if ( argc < 4 ) {
	fprintf(stderr,"usage: testdate from by to\n");
	return 1;
    }

    dayf = strtol( argv[ 1 ] , NULL , 0 );
    dayb = strtol( argv[ 2 ] , NULL , 0 );
    dayt = strtol( argv[ 3 ] , NULL , 0 );

    abort = 0;
    dayn = dayf;
    for (;;) {

	jdn_to_ymdg( dayn , & gy , & gm , & gd , & gl , & gn );
	jdn_to_ymdj( dayn , & jy , & jm , & jd , & jl , & jn );

	if ( dayn < 0 ) {
	    w = ( dayn + ( ( 6 - dayn ) / 7 ) * 7 + 1 ) % 7;
	}
	else if ( dayn < 6 ) {
	    w = ( dayn + 1 ) % 7;
	}
	else {
	    w = ( dayn - 6 ) % 7;
	}

	printf("%7ld G=%04ld/%02u/%02u J=%04ld/%02u/%02u %s (%7ld %7ld)\n",
	       dayn,
	       gy-(gy<1),gm+1,gd+1,
	       jy-(jy<1),jm+1,jd+1,
	       daylist[w],
	       ymdg_to_jdn(gy,gm,gd),
	       ymdj_to_jdn(jy,jm,jd)
	       );
	fflush(stdout);

	dayx = ymdg_to_jdn( gy , gm , gd );
	if ( dayx != dayn ) {
	    printf("OOPS!!  G day mismatch: %10ld != %10ld\n",dayn,dayx);
	    abort = 1;
	}

	dayx = ymdj_to_jdn( jy , jm , jd );
	if ( dayx != dayn ) {
	    printf("OOPS!!  J day mismatch: %10ld != %10ld\n",dayn,dayx);
	    abort = 1;
	}

	if ( abort ) return 1;

	if ( dayn == dayt ) break;

	if ( dayb > 0 && dayn > dayt ) break;
	if ( dayb < 0 && dayn < dayt ) break;

	dayn += dayb;
    }

    return 0;
}
#pragma section end CODE

#undef FUNCTION_NAME
