/***********************************************************************\
| Copyright  1997, by Philip David Howard - all rights reserved	|
|									|
| author	Philip D. Howard					|
| email		phil@txics.com, phil@milepost.com			|
| postal	Suite 129						|
|		17023 Preston Road					|
|		Dallas, Texas  75230					|
\***********************************************************************/

#include <stddef.h>
#include <time.h>

#include "days.h"

#pragma section begin SYNOPSIS
/***********************************************************************\
| function	tm_to_jdn						|
|									|
| purpose	Convert ANSI Standard C struct tm to a Julian Day	|
|		Number.							|
|									|
| argument	1 (struct tm *) time structure to be converted		|
|									|
| returns	(long) Julian Day Number				|
|									|
| note		A Julian Day Number (JDN) is a Julian Date rounded	|
|		to an integer.  The Julian Date is commonly used in	|
|		astronomy to identify dates in ephemeral data and	|
|		formulas.  The JDN is a number that is the same		|
|		through the ordinary civil day and can be used for	|
|		calendar references.					|
|									|
| ref		Explanatory Supplement to the Astronomical Almanac,	|
|		P. Kenneth Seidelmann, editor  [ISBN 0-935702-68-7]	|
|		http://www.amazon.com/exec/obidos/ISBN=0935702687	|
\***********************************************************************/
#pragma section end SYNOPSIS

#define FUNCTION_NAME "tm_to_jdn"

#pragma section begin FUNCTION
long
tm_to_jdn (
	struct tm *	tm_p
)
#pragma section end FUNCTION

#pragma section begin CODE
{
    return ymdg_to_jdn((long)		(tm_p->tm_year + 1900),
		       (unsigned int)	(tm_p->tm_mon ),
		       (unsigned int)	(tm_p->tm_mday - 1)
    );
}
#pragma section end CODE

#undef FUNCTION_NAME
